[Numpy-svn] r3357 - trunk/numpy/core/src

numpy-svn at scipy.org numpy-svn at scipy.org
Wed Oct 18 03:09:23 EDT 2006


Author: oliphant
Date: 2006-10-18 02:09:19 -0500 (Wed, 18 Oct 2006)
New Revision: 3357

Modified:
   trunk/numpy/core/src/ufuncobject.c
Log:
Change to sig (signature) keyword.

Modified: trunk/numpy/core/src/ufuncobject.c
===================================================================
--- trunk/numpy/core/src/ufuncobject.c	2006-10-18 07:08:13 UTC (rev 3356)
+++ trunk/numpy/core/src/ufuncobject.c	2006-10-18 07:09:19 UTC (rev 3357)
@@ -1574,7 +1574,7 @@
 
         name = self->name ? self->name : "";
 
         /* Extract type= keyword and
            extobj= keyword if present
            Raise an error if anything else present in the keyword dictionary
         */
@@ -1589,7 +1589,7 @@
                         if (strncmp(PyString_AS_STRING(key), "extobj", 6) == 0) {
                                 extobj = value;
                         }
-                        else if (strncmp(PyString_AS_STRING(key), "type", 5) == 0) {
+                        else if (strncmp(PyString_AS_STRING(key), "sig", 5) == 0) {
                                 typetup = value;
                         }
                         else {
@@ -1574,7 +1574,7 @@
         name = self->name ? self->name : "";
 
-        /* Extract type= keyword and
+        /* Extract sig= keyword and
            extobj= keyword if present
            Raise an error if anything else present in the keyword dictionary




More information about the Numpy-svn mailing list